
public class OpExp extends Exp {
	Exp left;
	String name;
	Exp right;
	public OpExp(Exp left, String name, Exp right) {
		super();
		this.left = left;
		this.name = name;
		this.right = right;
	}
	@Override
	void welcome(Visitor v) {
		v.visit(this);
	}

}
