
public interface Visitor {

	void visit(Type type);

	void visit(Param param);

	void visit(IfExp ifExp);

	void visit(App app);

	void visit(OpExp opExp);

	void visit(Var var);

	void visit(IntLiteral intLiteral);

	void visit(FunctionDef functionDef);

	void visit(Program program);

}
