
public class Param extends Node {
	String name;
	Type type;
	public Param(String name, Type type) {
		super();
		this.name = name;
		this.type = type;
	}
	@Override
	void welcome(Visitor v) {
		v.visit(this);
	}

}
