import java.util.List;


public class FunctionDef extends Node {
	String name;
	List<Param> params;
	Exp body;
	Type resultType;
	public FunctionDef(String name, List<Param> params, Exp body,
			Type resultType) {
		super();
		this.name = name;
		this.params = params;
		this.body = body;
		this.resultType = resultType;
	}
	@Override
	void welcome(Visitor v) {
		v.visit(this);
	}

}
