import java.util.List;


public class Program extends Node{
	List<FunctionDef> functions;
	Exp e;
	public Program(List<FunctionDef> functions, Exp e) {
		super();
		this.functions = functions;
		this.e = e;
	}
	@Override
	void welcome(Visitor v) {
		v.visit(this);
	}

}
