import java.util.List;


public class App extends Exp {
	String functionName;
	List<Exp> args;
	public App(String functionName,List<Exp> args) {
		super();
		this.args = args;
		this.functionName = functionName;
	}
	@Override
	void welcome(Visitor v) {
		v.visit(this);
	}

}
