
public class IfExp extends Exp {
	Exp cond;
	Exp alt1;
	Exp alt2;
	public IfExp(Exp cond, Exp alt1, Exp alt2) {
		super();
		this.cond = cond;
		this.alt1 = alt1;
		this.alt2 = alt2;
	}
	@Override
	void welcome(Visitor v) {
		v.visit(this);
	}

}
